antares.apps.user.templatetags package
======================================

Submodules
----------

antares.apps.user.templatetags.auth\_tags module
------------------------------------------------

.. automodule:: antares.apps.user.templatetags.auth_tags
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.user.templatetags
   :members:
   :undoc-members:
   :show-inheritance:
